@@ -7,7 +7,7 @@ Author: Prabal Pathak
 
 
 from sqlalchemy.orm import Session
-from ..authentication.auth_settings import pwd_context
+from authentication.auth_settings import pwd_context
 from . import models, schema
 
 
