@@ -5,8 +5,8 @@ Author: Prabal Pathak
 """
 from fastapi import FastAPI
 from fastapi.responses import JSONResponse
-from .database import database
-from .authentication.auth_utils import router
+from database import database
+from authentication.auth_utils import router
 
 database.Base.metadata.create_all(bind=database.engine)  # create all tables
 app = FastAPI()
